#ifndef _PACKINGDLG_CPP
#define _PACKINGDLG_CPP
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#include <Windows.H>
#include <Stdio.H>
#include <ShlOBJ.H>
#include <Stdlib.H>

#include "../Resources/Resource.H"

#include "../Source/NSWFL.H"
#include "../Source/Package.H"
#include "../Source/Entry.H"

#include "../Dialogs/MainDlg.H"
#include "../Dialogs/OpenPassDlg.H"

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

//---------------------(Variable Declarations)
HWND PackingDialog_hWnd = NULL;
HWND PackingStatusText_hWnd = NULL;
HWND PackingActionText_hWnd = NULL;
HWND PackingStatusBar_hWnd  = NULL;
HWND PackingMulButton_hWnd  = NULL;
HWND FileStatusBar_hWnd     = NULL;

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

BOOL CALLBACK PackingDialog(HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM lParam)
{
    //--------------------------------------------------------------------------

    static HMENU SystemMenu = NULL;
    static HWND Animation_hWnd = NULL;
    static HWND AVIFrame_hWnd = NULL;

    //--------------------------------------------------------------------------

    if(uMsg == WM_INITDIALOG) // Received A Initilize Dialog Message
    {
        PackingDialog_hWnd = hWnd;

		fFileProgress = 0;

        SystemMenu = GetSystemMenu(hWnd, FALSE);
        AppendMenu(SystemMenu, MF_SEPARATOR, 0, 0);
        AppendMenu(SystemMenu, MF_STRING, 1000, "About");

        SendMessage(hWnd, (UINT)WM_SETTEXT, (WPARAM)0, (LPARAM)gsTitleCaption);
        SendMessage(hWnd, WM_SETICON, TRUE, (LPARAM) LoadIcon(ghAppInstance, MAKEINTRESOURCE(IDI_MAIN)) );

        AVIFrame_hWnd          = GetDlgItem(hWnd, IDC_AVIFRAME);
        PackingActionText_hWnd = GetDlgItem(hWnd, IDC_ACTION);
        PackingMulButton_hWnd  = GetDlgItem(hWnd, IDC_MULBUTTON);
        PackingStatusBar_hWnd  = GetDlgItem(hWnd, IDC_PROGRESS);
        FileStatusBar_hWnd     = GetDlgItem(hWnd, IDC_FILEPROGRESS);

		PackingStatusText_hWnd = GetDlgItem(hWnd, IDC_STATUSTEXT);

        Animation_hWnd = Animate_Create(AVIFrame_hWnd, 100, WS_CHILD|ACS_TRANSPARENT|ACS_AUTOPLAY, ghAppInstance);

		SendMessage(FileStatusBar_hWnd, PBM_SETRANGE, 0, (LPARAM) MAKELPARAM(0, 100));
		
		if(gdwCurrentJobType == JOB_TYPE_ADDINGFILES)
		{
			Set_Text(PackingMulButton_hWnd, "Stop");
		}
		
		if(gdwCurrentJobType == JOB_TYPE_PACKING_DIR || gdwCurrentJobType == JOB_TYPE_PACKING_FIL || gdwCurrentJobType == JOB_TYPE_ADDINGFILES)
        {
            Animate_Open(Animation_hWnd, MAKEINTRESOURCE(IDR_ENCRYPTAVI));
        }
        else{
            Animate_Open(Animation_hWnd, MAKEINTRESOURCE(IDR_DECRYPTAVI));
        }

        ShowWindow(Animation_hWnd, SW_SHOW);

        SendMessage(PackingStatusBar_hWnd, PBM_SETPOS, 0, (LPARAM) 0);

        CenterWindow(hWnd);

        ResumeThread(hWorker_Thread_Handle);

        SetTimer(hWnd, 0, 100, NULL);

        return TRUE; // Return TRUE to set the keyboard focus, Otherwise return FALSE
    }

    //--------------------------------------------------------------------------

    if(uMsg == WM_TIMER)
    {
        SendMessage(PackingStatusBar_hWnd, PBM_SETPOS, dwPackageProgress, (LPARAM) 0);
		SendMessage(FileStatusBar_hWnd, PBM_SETPOS, (DWORD)fFileProgress, (LPARAM) 0);
        return FALSE;
    }

    //--------------------------------------------------------------------------

    if(uMsg == WM_COMMAND)
    {
        if(wParam == IDC_MULBUTTON)
        {
            EnableWindow(PackingMulButton_hWnd, FALSE);
            Set_Text(PackingStatusText_hWnd, "Please wait... Cancelling.");
            gdwCurrentJobType = JOB_TYPE_CANCEL;
            return TRUE;
        }

        return FALSE;
    }

    //--------------------------------------------------------------------------

	if(uMsg == WM_PAINT)
    {
        HDC ThisHDC;
        PAINTSTRUCT ThisPS;

        ThisHDC = BeginPaint(hWnd, &ThisPS);

        // Any painting should be done here

        EndPaint(hWnd, &ThisPS);
        return TRUE;
    }

    //--------------------------------------------------------------------------

    if(uMsg == WM_SYSCOMMAND) // Received A System Menu Message
    {
        if(LOWORD(wParam) == 1000) //- About (SysMenu Command)
        {
            _AboutDialogInfo ADI;
    
            ADI.DisplayIcon  = LoadIcon(ghAppInstance, MAKEINTRESOURCE(IDI_MAIN));
            ADI.TitleCaption = gsTitleCaption;
            ADI.FileVersion  = gsFileVersion;
            ADI.BuildDate    = __DATE__;
            ADI.BuildTime    = __TIME__;
            ADI.CopyRight    = gsAppCopyRight;
            ADI.OwnerHandle  = hWnd;

            NetLogo(&ADI);
            return TRUE;
        }

        return FALSE;
    }

    //--------------------------------------------------------------------------

    if(uMsg == WM_CLOSE)  // Received Close Message
    {
        gdwCurrentJobType = JOB_TYPE_CANCEL;
        EndDialog(hWnd, 0);
        DestroyWindow(hWnd);
        return TRUE;
    }

    //--------------------------------------------------------------------------

    return FALSE;
}

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
#endif

